@@ -1,5 +1,5 @@
 resQQplot.fun <-
-function(nsim,objres, covariates,clevel=0.95,cores=NULL,
+function(nsim,objres, covariates,clevel=0.95,cores=1,
 n=100, tit='')
 {
 
@@ -14,13 +14,13 @@ if (is.null(tit)) tit<-objres$obFPP$tit
 t<-objres$obFPP$t
 h<-objres$res
 lint<-objres$lint
-if (is.null(cores)) cores<-detectCores()
 if (is.null(t)) t<-c(1:length(lambda))
 if (typeRes=='Raw') res<-objres$RawRes
 else res<-objres$ScaRes$ScaRes
 
 cl<-makeCluster(cores)
 clusterExport(cl, c('resSim.fun','simNHP.fun','buscar','fitPP.fun','CalcResD.fun','CalcRes.fun'))
+writeLines('Calculating...',sep=' ')
 Mres <- parSapply(cl, c(1:nsim), FUN=resSim.fun,lambda=lambda, 
 covariates=covariates, beta=beta, lint=lint, t=t, tind=tind, typeI=typeI, typeRes=typeRes,h=h, n=n)
 stopCluster(cl)
@@ -31,6 +31,7 @@ resmed<-apply(Mres, FUN=mean,MARGIN=1, na.rm=TRUE)
 
 aux<-sort.list(resmed)
 scay<-c(min(resmed,ressup,resinf, na.rm=T),max(resmed,ressup,resinf, na.rm=T))
+writeLines('Done')
 dev.new() 
 marca<-as.numeric((res<=ressup)&(res>=resinf))
 plot(resmed,res,ylab='empirical quantile of the residuals',
